export_schema

Function export_schema 

pub fn export_schema(tree: &FormTree, root: FormNodeId) -> FormSchema
Extract a schema from a FormTree.

Returns a FormSchema with an entry for every field and draw node, including type hints, repetition rules, and scripts.