Module api

Module api 

The ideal top-level API facade for the PDFluent SDK.

This module defines the intended public surface of the PDFluent library, following the “Zero-Config First Success”, “Pit of Success”, and “Progressive Disclosure” design principles.

Re-exports

pub use crate::api_error::Error;

Structs

Document
The main entry point for a PDF Document.
FormField
An interactive form field.
Metadata
Document metadata.
Page
Represents a single page within a Document.
ReadOptions
Options for reading a PDF.
SaveOptions
Options for saving a PDF.
Signature
A digital signature within the document.
TextBlock
A structured block of text from a PDF.
WatermarkOptions

Enums

ImageFormat
PdfFormat
PdfSource
Input source for a PDF document.

Functions

read
Reads a PDF document from a file path or bytes, using default options.
read_with
Reads a PDF document with custom options (e.g., providing a password).