pub fn export_schema(tree: &FormTree, root: FormNodeId) -> FormSchemaExpand description
Extract a schema from a FormTree.
Returns a FormSchema with an entry for every field and draw node,
including type hints, repetition rules, and scripts.
pub fn export_schema(tree: &FormTree, root: FormNodeId) -> FormSchemaExtract a schema from a FormTree.
Returns a FormSchema with an entry for every field and draw node,
including type hints, repetition rules, and scripts.